@@ -4,15 +4,13 @@ use strict;
 use warnings;
 use vars qw( $VERSION @EXPORT @EXPORT_OK @ISA $CurrentPackage @IncludeLibs $ScanFileRE );
 
-$VERSION   = '1.25';
+$VERSION   = '1.26';
 @EXPORT    = qw( scan_deps scan_deps_runtime );
 @EXPORT_OK = qw( scan_line scan_chunk add_deps scan_deps_runtime path_to_inc_name );
 
 use Config;
 require Exporter;
 our @ISA = qw(Exporter);
-use constant dl_ext  => ".$Config{dlext}";
-use constant lib_ext => $Config{lib_ext};
 use constant is_insensitive_fs => (
     -s $0 
         and (-s lc($0) || -1) == (-s uc($0) || -1)
@@ -332,7 +330,7 @@ my %Preload = (
     'ExtUtils/MakeMaker.pm'             => sub {
         grep /\bMM_/, _glob_in_inc('ExtUtils', 1);
     },
-    'FFI/Platypus'                      => 'sub',
+    'FFI/Platypus.pm'                   => 'sub',
     'File/Basename.pm'                  => [qw( re.pm )],
     'File/BOM.pm'                       => [qw( Encode/Unicode.pm )],
     'File/HomeDir.pm'                   => 'sub',
@@ -341,6 +339,7 @@ my %Preload = (
         map { my $name = $_; $name =~ s!::!/!g; "$name.pm" } @File::Spec::ISA;
     },
     'Gtk2.pm'                           => [qw( Cairo.pm )], # Gtk2.pm does: eval "use Cairo;"
+    'HTTP/Entity/Parser.pm'             => 'sub',
     'HTTP/Message.pm'                   => [qw( URI/URL.pm URI.pm )],
     'Image/ExifTool.pm'                 => sub {
         return(
@@ -365,6 +364,9 @@ my %Preload = (
         # but accept JSON::XS, too (because JSON.pm might use it if present)
         return( grep /^JSON\/(PP|XS)/, _glob_in_inc('JSON', 1) );
     },
+    'JSON/MaybeXS.pm'                   => [qw(
+        Cpanel/JSON/XS.pm JSON/XS.pm JSON/PP.pm 
+    )],
     'List/MoreUtils.pm'                 => 'sub',
     'List/SomeUtils.pm'                 => 'sub',
     'Locale/Maketext/Lexicon.pm'        => 'sub',
@@ -1108,15 +1110,8 @@ sub add_deps {
 
             foreach (_glob_in_inc("auto/$path")) {
                 next if $_->{file} =~ m{\bauto/$path/.*/};  # weed out subdirs
-                next if $_->{name} =~ m{/\.(?:exists|packlist)$};
-                my ($ext,$type);
-                $ext = lc($1) if $_->{name} =~ /(\.[^.]+)$/;
-                if (defined $ext) {
-                    next if $ext eq lc(lib_ext());
-                    $type = 'shared' if $ext eq lc(dl_ext());
-                    $type = 'autoload' if ($ext eq '.ix' or $ext eq '.al');
-                }
-                $type ||= 'data';
+                next if $_->{name} =~ m{/(?:\.exists|\.packlist|\Q$Config{lib_ext}\E)$};
+                $type = _gettype($_->{name});
 
                 _add_info( rv     => $rv,        module  => $_->{name},
                            file   => $_->{file}, used_by => $module,
@@ -1386,7 +1381,7 @@ BEGIN { my $_0 = $ENV{MSD_ORIGINAL_FILE}; *0 = \$_0; }
     # drop refs from @_INC
     @_INC = grep { !ref $_ } @_INC;
 
-    my $dlext = $Config::Config{dlext};
+    my $dlext = $Config{dlext};
     my @dlls = grep { defined $_ && -e $_ } Module::ScanDeps::DataFeed::_dl_shared_objects();
     my @shared_objects = @dlls; 
     push @shared_objects, grep { s/\Q.$dlext\E$/\.bs/ && -e $_ } @dlls;
@@ -1419,7 +1414,6 @@ BEGIN { my $_0 = $ENV{MSD_ORIGINAL_FILE}; *0 = \$_0; }
         return if $mod eq 'B';
         return unless defined &{"$mod\::bootstrap"};
 
-        my $dl_ext = $Config::Config{dlext};
 
         # cf. DynaLoader.pm
         my @modparts = split(/::/, $mod);
@@ -1427,7 +1421,7 @@ BEGIN { my $_0 = $ENV{MSD_ORIGINAL_FILE}; *0 = \$_0; }
         my $modpname = join('/', @modparts);
 
         foreach my $dir (@_INC) {
-            my $file = "$dir/auto/$modpname/$modfname.$dl_ext";
+            my $file = "$dir/auto/$modpname/$modfname.$Config{dlext}";
             return $file if -r $file;
         }
         return;
@@ -1505,11 +1499,10 @@ sub _info2rv {
 
 sub _gettype {
     my $name = shift;
-    my $dlext = quotemeta(dl_ext());
 
-    return 'autoload' if $name =~ /(?:\.ix|\.al)$/i;
+    return 'autoload' if $name =~ /\.(?:ix|al|bs)$/i;
     return 'module'   if $name =~ /\.p[mh]$/i;
-    return 'shared'   if $name =~ /\.$dlext$/i;
+    return 'shared'   if $name =~ /\.\Q$Config{dlext}\E$/i;
     return 'data';
 }
 
@@ -1631,6 +1624,10 @@ scripts that contains prerequisite modules; this module supports two
 such projects, L<PAR> and L<App::Packer>.  Please see their respective
 documentations on CPAN for further information.
 
+Other modules which accomplish the same goal with different approach:
+L<Module::ExtractUse>, L<Perl::PrereqScanner>, L<Perl::PrereqScanner::Lite>,
+L<Perl::PrereqScanner::NotQuiteLite>.
+
 =head1 AUTHORS
 
 Audrey Tang E<lt>cpan@audreyt.orgE<gt>
